@@ -64,6 +64,7 @@ def pytest_addoption(parser: Any) -> None:
     parser.addoption(
         "--event-loop",
         action="store",
+        dest="event_loop_type",
         default="asyncio",
         choices=["asyncio", "uvloop"],
         help="event loop to run tests on",
@@ -81,7 +82,7 @@ original_event_loop_policy = None
 
 def pytest_sessionstart(session: pytest.Session) -> None:
     # Install the uvloop event loop policy globally, per session
-    loop_type = session.config.getoption("--event-loop")
+    loop_type = session.config.getoption("event_loop_type")
     if loop_type == "uvloop":
         if not HAS_UVLOOP:
             raise RuntimeError("uvloop not installed.")
@@ -89,6 +90,16 @@ def pytest_sessionstart(session: pytest.Session) -> None:
         uvloop.install()  # type: ignore
 
 
+def pytest_collection_modifyitems(
+    config: pytest.Config, items: list[pytest.Item]
+) -> None:
+    if config.getoption("event_loop_type") == "uvloop":
+        for item in items:
+            if "skip_if_uvloop" in item.keywords:
+                marker = pytest.mark.skip(reason="skipped on uvloop")
+                item.add_marker(marker)
+
+
 @pytest_asyncio.fixture
 def debug_event_loop(
     event_loop: asyncio.AbstractEventLoop,
@@ -143,6 +154,11 @@ def message_str(recipient_str: str, sender_str: str) -> str:
     )
 
 
+@pytest.fixture(scope="session")
+def message_bytes(message_str: str) -> bytes:
+    return message_str.encode("ascii")
+
+
 @pytest.fixture(scope="session")
 def smtpd_class() -> type[SMTPD]:
     return TestSMTPD
@@ -307,16 +323,39 @@ def mime_message(
     return message
 
 
-@pytest.fixture(scope="function", params=["mime_multipart", "compat32"])
+@pytest.fixture(scope="function")
+def email_message(recipient_str: str, sender_str: str) -> email.message.EmailMessage:
+    message = email.message.EmailMessage()
+    message["To"] = recipient_str
+    message["From"] = sender_str
+    message["Subject"] = "A message"
+    message.set_payload("Hello World")
+
+    return message
+
+
+@pytest.fixture(scope="function")
 def message(
-    request: ParamFixtureRequest,
+    request: pytest.FixtureRequest,
+    email_message: email.message.EmailMessage,
     compat32_message: email.message.Message,
-    mime_message: email.message.EmailMessage,
-) -> Union[email.message.Message, email.message.EmailMessage]:
-    if request.param == "compat32":
+    mime_message: email.mime.multipart.MIMEMultipart,
+    message_str: str,
+    message_bytes: bytes,
+) -> Union[email.message.EmailMessage, email.message.Message, str, bytes]:
+    if not hasattr(request, "param"):
+        return email_message
+
+    if request.param == "compat32_message":
         return compat32_message
-    else:
+    elif request.param == "mime_message":
         return mime_message
+    elif request.param == "str":
+        return message_str
+    elif request.param == "bytes":
+        return message_bytes
+    else:
+        return email_message
 
 
 # Server helpers and factories #
@@ -359,14 +398,8 @@ def smtpd_auth_callback(
     return auth_callback
 
 
-@pytest.fixture(
-    scope="function",
-    params=(str, bytes, Path),
-    ids=("str", "bytes", "pathlike"),
-)
-def socket_path(
-    request: ParamFixtureRequest, tmp_path: Path
-) -> Union[str, bytes, Path]:
+@pytest.fixture(scope="function")
+def socket_path(tmp_path: Path) -> Path:
     if sys.platform.startswith("darwin"):
         # Work around OSError: AF_UNIX path too long
         tmp_dir = Path("/tmp")  # nosec
@@ -379,9 +412,7 @@ def socket_path(
         index += 1
         socket_path = tmp_dir / f"aiosmtplib-test{index}"
 
-    typed_socket_path: Union[str, bytes, Path] = request.param(socket_path)
-
-    return typed_socket_path
+    return socket_path
 
 
 # Servers #
